@@ -62,13 +62,13 @@ def common(**kwargs):
         DEFAULT_FILE_STORAGE = 'storages.backends.s3boto3.S3Boto3Storage'
         S3_URL = 'https://%s/' % AWS_S3_CUSTOM_DOMAIN
         # static data, e.g. css, js, etc.
-        STATICFILES_STORAGE = 'storages.backends.s3boto3.S3Boto3Storage'
+        STATICFILES_STORAGE = 'ccnmtlsettings.storage.CompressorS3Boto3Storage'
         STATIC_URL = 'https://%s/media/' % AWS_S3_CUSTOM_DOMAIN
         COMPRESS_ENABLED = True
         COMPRESS_OFFLINE = True
         COMPRESS_ROOT = STATIC_ROOT
         COMPRESS_URL = STATIC_URL
-        COMPRESS_STORAGE = 'storages.backends.s3boto3.S3Boto3Storage'
+        COMPRESS_STORAGE = 'ccnmtlsettings.storage.CompressorS3Boto3Storage'
 
     LOGGING = {
         'version': 1,
